==> guile-2.0.3.tar.gz: guile-2.0.3/libguile/cpp-E.c <==
#ifdef E2BIG
scm_c_define ("E2BIG", scm_from_int (E2BIG));
#endif
#ifdef EACCES
scm_c_define ("EACCES", scm_from_int (EACCES));
#endif
#ifdef EADDRINUSE
scm_c_define ("EADDRINUSE", scm_from_int (EADDRINUSE));
#endif
#ifdef EADDRNOTAVAIL
scm_c_define ("EADDRNOTAVAIL", scm_from_int (EADDRNOTAVAIL));
#endif
#ifdef EADV
scm_c_define ("EADV", scm_from_int (EADV));
#endif
#ifdef EAFNOSUPPORT
scm_c_define ("EAFNOSUPPORT", scm_from_int (EAFNOSUPPORT));
#endif
#ifdef EAGAIN
scm_c_define ("EAGAIN", scm_from_int (EAGAIN));
#endif
#ifdef EALREADY
scm_c_define ("EALREADY", scm_from_int (EALREADY));
#endif
#ifdef EBADE
scm_c_define ("EBADE", scm_from_int (EBADE));
#endif
#ifdef EBADF
scm_c_define ("EBADF", scm_from_int (EBADF));
#endif
#ifdef EBADFD
scm_c_define ("EBADFD", scm_from_int (EBADFD));
#endif
#ifdef EBADMSG
scm_c_define ("EBADMSG", scm_from_int (EBADMSG));
#endif
#ifdef EBADR
scm_c_define ("EBADR", scm_from_int (EBADR));
#endif
#ifdef EBADRQC
scm_c_define ("EBADRQC", scm_from_int (EBADRQC));
#endif
#ifdef EBADSLT
scm_c_define ("EBADSLT", scm_from_int (EBADSLT));
#endif
#ifdef EBFONT
scm_c_define ("EBFONT", scm_from_int (EBFONT));
#endif
#ifdef EBUSY
scm_c_define ("EBUSY", scm_from_int (EBUSY));
#endif
#ifdef ECANCELED
scm_c_define ("ECANCELED", scm_from_int (ECANCELED));
#endif
#ifdef ECHILD
scm_c_define ("ECHILD", scm_from_int (ECHILD));
#endif
#ifdef ECHRNG
scm_c_define ("ECHRNG", scm_from_int (ECHRNG));
#endif
#ifdef ECOMM
scm_c_define ("ECOMM", scm_from_int (ECOMM));
#endif
#ifdef ECONNABORTED
scm_c_define ("ECONNABORTED", scm_from_int (ECONNABORTED));
#endif
#ifdef ECONNREFUSED
scm_c_define ("ECONNREFUSED", scm_from_int (ECONNREFUSED));
#endif
#ifdef ECONNRESET
scm_c_define ("ECONNRESET", scm_from_int (ECONNRESET));
#endif
#ifdef EDEADLK
scm_c_define ("EDEADLK", scm_from_int (EDEADLK));
#endif
#ifdef EDEADLOCK
scm_c_define ("EDEADLOCK", scm_from_int (EDEADLOCK));
#endif
#ifdef EDESTADDRREQ
scm_c_define ("EDESTADDRREQ", scm_from_int (EDESTADDRREQ));
#endif
#ifdef EDOM
scm_c_define ("EDOM", scm_from_int (EDOM));
#endif
#ifdef EDOTDOT
scm_c_define ("EDOTDOT", scm_from_int (EDOTDOT));
#endif
#ifdef EDQUOT
scm_c_define ("EDQUOT", scm_from_int (EDQUOT));
#endif
#ifdef EEXIST
scm_c_define ("EEXIST", scm_from_int (EEXIST));
#endif
#ifdef EFAULT
scm_c_define ("EFAULT", scm_from_int (EFAULT));
#endif
#ifdef EFBIG
scm_c_define ("EFBIG", scm_from_int (EFBIG));
#endif
#ifdef EHOSTDOWN
scm_c_define ("EHOSTDOWN", scm_from_int (EHOSTDOWN));
#endif
#ifdef EHOSTUNREACH
scm_c_define ("EHOSTUNREACH", scm_from_int (EHOSTUNREACH));
#endif
#ifdef EIDRM
scm_c_define ("EIDRM", scm_from_int (EIDRM));
#endif
#ifdef EILSEQ
scm_c_define ("EILSEQ", scm_from_int (EILSEQ));
#endif
#ifdef EINPROGRESS
scm_c_define ("EINPROGRESS", scm_from_int (EINPROGRESS));
#endif
#ifdef EINTR
scm_c_define ("EINTR", scm_from_int (EINTR));
#endif
#ifdef EINVAL
scm_c_define ("EINVAL", scm_from_int (EINVAL));
#endif
#ifdef EIO
scm_c_define ("EIO", scm_from_int (EIO));
#endif
#ifdef EISCONN
scm_c_define ("EISCONN", scm_from_int (EISCONN));
#endif
#ifdef EISDIR
scm_c_define ("EISDIR", scm_from_int (EISDIR));
#endif
#ifdef EISNAM
scm_c_define ("EISNAM", scm_from_int (EISNAM));
#endif
#ifdef EKEYEXPIRED
scm_c_define ("EKEYEXPIRED", scm_from_int (EKEYEXPIRED));
#endif
#ifdef EKEYREJECTED
scm_c_define ("EKEYREJECTED", scm_from_int (EKEYREJECTED));
#endif
#ifdef EKEYREVOKED
scm_c_define ("EKEYREVOKED", scm_from_int (EKEYREVOKED));
#endif
#ifdef EL2HLT
scm_c_define ("EL2HLT", scm_from_int (EL2HLT));
#endif
#ifdef EL2NSYNC
scm_c_define ("EL2NSYNC", scm_from_int (EL2NSYNC));
#endif
#ifdef EL3HLT
scm_c_define ("EL3HLT", scm_from_int (EL3HLT));
#endif
#ifdef EL3RST
scm_c_define ("EL3RST", scm_from_int (EL3RST));
#endif
#ifdef ELIBACC
scm_c_define ("ELIBACC", scm_from_int (ELIBACC));
#endif
#ifdef ELIBBAD
scm_c_define ("ELIBBAD", scm_from_int (ELIBBAD));
#endif
#ifdef ELIBEXEC
scm_c_define ("ELIBEXEC", scm_from_int (ELIBEXEC));
#endif
#ifdef ELIBMAX
scm_c_define ("ELIBMAX", scm_from_int (ELIBMAX));
#endif
#ifdef ELIBSCN
scm_c_define ("ELIBSCN", scm_from_int (ELIBSCN));
#endif
#ifdef ELNRNG
scm_c_define ("ELNRNG", scm_from_int (ELNRNG));
#endif
#ifdef ELOOP
scm_c_define ("ELOOP", scm_from_int (ELOOP));
#endif
#ifdef EMEDIUMTYPE
scm_c_define ("EMEDIUMTYPE", scm_from_int (EMEDIUMTYPE));
#endif
#ifdef EMFILE
scm_c_define ("EMFILE", scm_from_int (EMFILE));
#endif
#ifdef EMLINK
scm_c_define ("EMLINK", scm_from_int (EMLINK));
#endif
#ifdef EMSGSIZE
scm_c_define ("EMSGSIZE", scm_from_int (EMSGSIZE));
#endif
#ifdef EMULTIHOP
scm_c_define ("EMULTIHOP", scm_from_int (EMULTIHOP));
#endif
#ifdef ENAMETOOLONG
scm_c_define ("ENAMETOOLONG", scm_from_int (ENAMETOOLONG));
#endif
#ifdef ENAVAIL
scm_c_define ("ENAVAIL", scm_from_int (ENAVAIL));
#endif
#ifdef ENETDOWN
scm_c_define ("ENETDOWN", scm_from_int (ENETDOWN));
#endif
#ifdef ENETRESET
scm_c_define ("ENETRESET", scm_from_int (ENETRESET));
#endif
#ifdef ENETUNREACH
scm_c_define ("ENETUNREACH", scm_from_int (ENETUNREACH));
#endif
#ifdef ENFILE
scm_c_define ("ENFILE", scm_from_int (ENFILE));
#endif
#ifdef ENOANO
scm_c_define ("ENOANO", scm_from_int (ENOANO));
#endif
#ifdef ENOBUFS
scm_c_define ("ENOBUFS", scm_from_int (ENOBUFS));
#endif
#ifdef ENOCSI
scm_c_define ("ENOCSI", scm_from_int (ENOCSI));
#endif
#ifdef ENODATA
scm_c_define ("ENODATA", scm_from_int (ENODATA));
#endif
#ifdef ENODEV
scm_c_define ("ENODEV", scm_from_int (ENODEV));
#endif
#ifdef ENOENT
scm_c_define ("ENOENT", scm_from_int (ENOENT));
#endif
#ifdef ENOEXEC
scm_c_define ("ENOEXEC", scm_from_int (ENOEXEC));
#endif
#ifdef ENOKEY
scm_c_define ("ENOKEY", scm_from_int (ENOKEY));
#endif
#ifdef ENOLCK
scm_c_define ("ENOLCK", scm_from_int (ENOLCK));
#endif
#ifdef ENOLINK
scm_c_define ("ENOLINK", scm_from_int (ENOLINK));
#endif
#ifdef ENOMEDIUM
scm_c_define ("ENOMEDIUM", scm_from_int (ENOMEDIUM));
#endif
#ifdef ENOMEM
scm_c_define ("ENOMEM", scm_from_int (ENOMEM));
#endif
#ifdef ENOMSG
scm_c_define ("ENOMSG", scm_from_int (ENOMSG));
#endif
#ifdef ENONET
scm_c_define ("ENONET", scm_from_int (ENONET));
#endif
#ifdef ENOPKG
scm_c_define ("ENOPKG", scm_from_int (ENOPKG));
#endif
#ifdef ENOPROTOOPT
scm_c_define ("ENOPROTOOPT", scm_from_int (ENOPROTOOPT));
#endif
#ifdef ENOSPC
scm_c_define ("ENOSPC", scm_from_int (ENOSPC));
#endif
#ifdef ENOSR
scm_c_define ("ENOSR", scm_from_int (ENOSR));
#endif
#ifdef ENOSTR
scm_c_define ("ENOSTR", scm_from_int (ENOSTR));
#endif
#ifdef ENOSYS
scm_c_define ("ENOSYS", scm_from_int (ENOSYS));
#endif
#ifdef ENOTBLK
scm_c_define ("ENOTBLK", scm_from_int (ENOTBLK));
#endif
#ifdef ENOTCONN
scm_c_define ("ENOTCONN", scm_from_int (ENOTCONN));
#endif
#ifdef ENOTDIR
scm_c_define ("ENOTDIR", scm_from_int (ENOTDIR));
#endif
#ifdef ENOTEMPTY
scm_c_define ("ENOTEMPTY", scm_from_int (ENOTEMPTY));
#endif
#ifdef ENOTNAM
scm_c_define ("ENOTNAM", scm_from_int (ENOTNAM));
#endif
#ifdef ENOTRECOVERABLE
scm_c_define ("ENOTRECOVERABLE", scm_from_int (ENOTRECOVERABLE));
#endif
#ifdef ENOTSOCK
scm_c_define ("ENOTSOCK", scm_from_int (ENOTSOCK));
#endif
#ifdef ENOTSUP
scm_c_define ("ENOTSUP", scm_from_int (ENOTSUP));
#endif
#ifdef ENOTTY
scm_c_define ("ENOTTY", scm_from_int (ENOTTY));
#endif
#ifdef ENOTUNIQ
scm_c_define ("ENOTUNIQ", scm_from_int (ENOTUNIQ));
#endif
#ifdef ENXIO
scm_c_define ("ENXIO", scm_from_int (ENXIO));
#endif
#ifdef EOPNOTSUPP
scm_c_define ("EOPNOTSUPP", scm_from_int (EOPNOTSUPP));
#endif
#ifdef EOVERFLOW
scm_c_define ("EOVERFLOW", scm_from_int (EOVERFLOW));
#endif
#ifdef EOWNERDEAD
scm_c_define ("EOWNERDEAD", scm_from_int (EOWNERDEAD));
#endif
#ifdef EPERM
scm_c_define ("EPERM", scm_from_int (EPERM));
#endif
#ifdef EPFNOSUPPORT
scm_c_define ("EPFNOSUPPORT", scm_from_int (EPFNOSUPPORT));
#endif
#ifdef EPIPE
scm_c_define ("EPIPE", scm_from_int (EPIPE));
#endif
#ifdef EPROTO
scm_c_define ("EPROTO", scm_from_int (EPROTO));
#endif
#ifdef EPROTONOSUPPORT
scm_c_define ("EPROTONOSUPPORT", scm_from_int (EPROTONOSUPPORT));
#endif
#ifdef EPROTOTYPE
scm_c_define ("EPROTOTYPE", scm_from_int (EPROTOTYPE));
#endif
#ifdef ERANGE
scm_c_define ("ERANGE", scm_from_int (ERANGE));
#endif
#ifdef EREMCHG
scm_c_define ("EREMCHG", scm_from_int (EREMCHG));
#endif
#ifdef EREMOTE
scm_c_define ("EREMOTE", scm_from_int (EREMOTE));
#endif
#ifdef EREMOTEIO
scm_c_define ("EREMOTEIO", scm_from_int (EREMOTEIO));
#endif
#ifdef ERESTART
scm_c_define ("ERESTART", scm_from_int (ERESTART));
#endif
#ifdef EROFS
scm_c_define ("EROFS", scm_from_int (EROFS));
#endif
#ifdef ESHUTDOWN
scm_c_define ("ESHUTDOWN", scm_from_int (ESHUTDOWN));
#endif
#ifdef ESOCKTNOSUPPORT
scm_c_define ("ESOCKTNOSUPPORT", scm_from_int (ESOCKTNOSUPPORT));
#endif
#ifdef ESPIPE
scm_c_define ("ESPIPE", scm_from_int (ESPIPE));
#endif
#ifdef ESRCH
scm_c_define ("ESRCH", scm_from_int (ESRCH));
#endif
#ifdef ESRMNT
scm_c_define ("ESRMNT", scm_from_int (ESRMNT));
#endif
#ifdef ESTALE
scm_c_define ("ESTALE", scm_from_int (ESTALE));
#endif
#ifdef ESTRPIPE
scm_c_define ("ESTRPIPE", scm_from_int (ESTRPIPE));
#endif
#ifdef ETIME
scm_c_define ("ETIME", scm_from_int (ETIME));
#endif
#ifdef ETIMEDOUT
scm_c_define ("ETIMEDOUT", scm_from_int (ETIMEDOUT));
#endif
#ifdef ETOOMANYREFS
scm_c_define ("ETOOMANYREFS", scm_from_int (ETOOMANYREFS));
#endif
#ifdef ETXTBSY
scm_c_define ("ETXTBSY", scm_from_int (ETXTBSY));
#endif
#ifdef EUCLEAN
scm_c_define ("EUCLEAN", scm_from_int (EUCLEAN));
#endif
#ifdef EUNATCH
scm_c_define ("EUNATCH", scm_from_int (EUNATCH));
#endif
#ifdef EUSERS
scm_c_define ("EUSERS", scm_from_int (EUSERS));
#endif
#ifdef EWOULDBLOCK
scm_c_define ("EWOULDBLOCK", scm_from_int (EWOULDBLOCK));
#endif
#ifdef EXDEV
scm_c_define ("EXDEV", scm_from_int (EXDEV));
#endif
#ifdef EXFULL
scm_c_define ("EXFULL", scm_from_int (EXFULL));
#endif

==> guile-2.0.14.tar.gz: guile-2.0.14/libguile/cpp-E.c <==
#ifdef E2BIG
scm_c_define ("E2BIG", scm_from_int (E2BIG));
#endif
#ifdef EACCES
scm_c_define ("EACCES", scm_from_int (EACCES));
#endif
#ifdef EADDRINUSE
scm_c_define ("EADDRINUSE", scm_from_int (EADDRINUSE));
#endif
#ifdef EADDRNOTAVAIL
scm_c_define ("EADDRNOTAVAIL", scm_from_int (EADDRNOTAVAIL));
#endif
#ifdef EADV
scm_c_define ("EADV", scm_from_int (EADV));
#endif
#ifdef EAFNOSUPPORT
scm_c_define ("EAFNOSUPPORT", scm_from_int (EAFNOSUPPORT));
#endif
#ifdef EAGAIN
scm_c_define ("EAGAIN", scm_from_int (EAGAIN));
#endif
#ifdef EALREADY
scm_c_define ("EALREADY", scm_from_int (EALREADY));
#endif
#ifdef EAUTH
scm_c_define ("EAUTH", scm_from_int (EAUTH));
#endif
#ifdef EBACKGROUND
scm_c_define ("EBACKGROUND", scm_from_int (EBACKGROUND));
#endif
#ifdef EBADE
scm_c_define ("EBADE", scm_from_int (EBADE));
#endif
#ifdef EBADF
scm_c_define ("EBADF", scm_from_int (EBADF));
#endif
#ifdef EBADFD
scm_c_define ("EBADFD", scm_from_int (EBADFD));
#endif
#ifdef EBADMSG
scm_c_define ("EBADMSG", scm_from_int (EBADMSG));
#endif
#ifdef EBADR
scm_c_define ("EBADR", scm_from_int (EBADR));
#endif
#ifdef EBADRPC
scm_c_define ("EBADRPC", scm_from_int (EBADRPC));
#endif
#ifdef EBADRQC
scm_c_define ("EBADRQC", scm_from_int (EBADRQC));
#endif
#ifdef EBADSLT
scm_c_define ("EBADSLT", scm_from_int (EBADSLT));
#endif
#ifdef EBFONT
scm_c_define ("EBFONT", scm_from_int (EBFONT));
#endif
#ifdef EBUSY
scm_c_define ("EBUSY", scm_from_int (EBUSY));
#endif
#ifdef ECANCELED
scm_c_define ("ECANCELED", scm_from_int (ECANCELED));
#endif
#ifdef ECHILD
scm_c_define ("ECHILD", scm_from_int (ECHILD));
#endif
#ifdef ECHRNG
scm_c_define ("ECHRNG", scm_from_int (ECHRNG));
#endif
#ifdef ECOMM
scm_c_define ("ECOMM", scm_from_int (ECOMM));
#endif
#ifdef ECONNABORTED
scm_c_define ("ECONNABORTED", scm_from_int (ECONNABORTED));
#endif
#ifdef ECONNREFUSED
scm_c_define ("ECONNREFUSED", scm_from_int (ECONNREFUSED));
#endif
#ifdef ECONNRESET
scm_c_define ("ECONNRESET", scm_from_int (ECONNRESET));
#endif
#ifdef ED
scm_c_define ("ED", scm_from_int (ED));
#endif
#ifdef EDEADLK
scm_c_define ("EDEADLK", scm_from_int (EDEADLK));
#endif
#ifdef EDEADLOCK
scm_c_define ("EDEADLOCK", scm_from_int (EDEADLOCK));
#endif
#ifdef EDESTADDRREQ
scm_c_define ("EDESTADDRREQ", scm_from_int (EDESTADDRREQ));
#endif
#ifdef EDIED
scm_c_define ("EDIED", scm_from_int (EDIED));
#endif
#ifdef EDOM
scm_c_define ("EDOM", scm_from_int (EDOM));
#endif
#ifdef EDOTDOT
scm_c_define ("EDOTDOT", scm_from_int (EDOTDOT));
#endif
#ifdef EDQUOT
scm_c_define ("EDQUOT", scm_from_int (EDQUOT));
#endif
#ifdef EEXIST
scm_c_define ("EEXIST", scm_from_int (EEXIST));
#endif
#ifdef EFAULT
scm_c_define ("EFAULT", scm_from_int (EFAULT));
#endif
#ifdef EFBIG
scm_c_define ("EFBIG", scm_from_int (EFBIG));
#endif
#ifdef EFTYPE
scm_c_define ("EFTYPE", scm_from_int (EFTYPE));
#endif
#ifdef EGRATUITOUS
scm_c_define ("EGRATUITOUS", scm_from_int (EGRATUITOUS));
#endif
#ifdef EGREGIOUS
scm_c_define ("EGREGIOUS", scm_from_int (EGREGIOUS));
#endif
#ifdef EHOSTDOWN
scm_c_define ("EHOSTDOWN", scm_from_int (EHOSTDOWN));
#endif
#ifdef EHOSTUNREACH
scm_c_define ("EHOSTUNREACH", scm_from_int (EHOSTUNREACH));
#endif
#ifdef EHWPOISON
scm_c_define ("EHWPOISON", scm_from_int (EHWPOISON));
#endif
#ifdef EIDRM
scm_c_define ("EIDRM", scm_from_int (EIDRM));
#endif
#ifdef EIEIO
scm_c_define ("EIEIO", scm_from_int (EIEIO));
#endif
#ifdef EILSEQ
scm_c_define ("EILSEQ", scm_from_int (EILSEQ));
#endif
#ifdef EINPROGRESS
scm_c_define ("EINPROGRESS", scm_from_int (EINPROGRESS));
#endif
#ifdef EINTR
scm_c_define ("EINTR", scm_from_int (EINTR));
#endif
#ifdef EINVAL
scm_c_define ("EINVAL", scm_from_int (EINVAL));
#endif
#ifdef EIO
scm_c_define ("EIO", scm_from_int (EIO));
#endif
#ifdef EISCONN
scm_c_define ("EISCONN", scm_from_int (EISCONN));
#endif
#ifdef EISDIR
scm_c_define ("EISDIR", scm_from_int (EISDIR));
#endif
#ifdef EISNAM
scm_c_define ("EISNAM", scm_from_int (EISNAM));
#endif
#ifdef EKEYEXPIRED
scm_c_define ("EKEYEXPIRED", scm_from_int (EKEYEXPIRED));
#endif
#ifdef EKEYREJECTED
scm_c_define ("EKEYREJECTED", scm_from_int (EKEYREJECTED));
#endif
#ifdef EKEYREVOKED
scm_c_define ("EKEYREVOKED", scm_from_int (EKEYREVOKED));
#endif
#ifdef EL2HLT
scm_c_define ("EL2HLT", scm_from_int (EL2HLT));
#endif
#ifdef EL2NSYNC
scm_c_define ("EL2NSYNC", scm_from_int (EL2NSYNC));
#endif
#ifdef EL3HLT
scm_c_define ("EL3HLT", scm_from_int (EL3HLT));
#endif
#ifdef EL3RST
scm_c_define ("EL3RST", scm_from_int (EL3RST));
#endif
#ifdef ELIBACC
scm_c_define ("ELIBACC", scm_from_int (ELIBACC));
#endif
#ifdef ELIBBAD
scm_c_define ("ELIBBAD", scm_from_int (ELIBBAD));
#endif
#ifdef ELIBEXEC
scm_c_define ("ELIBEXEC", scm_from_int (ELIBEXEC));
#endif
#ifdef ELIBMAX
scm_c_define ("ELIBMAX", scm_from_int (ELIBMAX));
#endif
#ifdef ELIBSCN
scm_c_define ("ELIBSCN", scm_from_int (ELIBSCN));
#endif
#ifdef ELNRNG
scm_c_define ("ELNRNG", scm_from_int (ELNRNG));
#endif
#ifdef ELOOP
scm_c_define ("ELOOP", scm_from_int (ELOOP));
#endif
#ifdef EMEDIUMTYPE
scm_c_define ("EMEDIUMTYPE", scm_from_int (EMEDIUMTYPE));
#endif
#ifdef EMFILE
scm_c_define ("EMFILE", scm_from_int (EMFILE));
#endif
#ifdef EMLINK
scm_c_define ("EMLINK", scm_from_int (EMLINK));
#endif
#ifdef EMSGSIZE
scm_c_define ("EMSGSIZE", scm_from_int (EMSGSIZE));
#endif
#ifdef EMULTIHOP
scm_c_define ("EMULTIHOP", scm_from_int (EMULTIHOP));
#endif
#ifdef ENAMETOOLONG
scm_c_define ("ENAMETOOLONG", scm_from_int (ENAMETOOLONG));
#endif
#ifdef ENAVAIL
scm_c_define ("ENAVAIL", scm_from_int (ENAVAIL));
#endif
#ifdef ENEEDAUTH
scm_c_define ("ENEEDAUTH", scm_from_int (ENEEDAUTH));
#endif
#ifdef ENETDOWN
scm_c_define ("ENETDOWN", scm_from_int (ENETDOWN));
#endif
#ifdef ENETRESET
scm_c_define ("ENETRESET", scm_from_int (ENETRESET));
#endif
#ifdef ENETUNREACH
scm_c_define ("ENETUNREACH", scm_from_int (ENETUNREACH));
#endif
#ifdef ENFILE
scm_c_define ("ENFILE", scm_from_int (ENFILE));
#endif
#ifdef ENOANO
scm_c_define ("ENOANO", scm_from_int (ENOANO));
#endif
#ifdef ENOBUFS
scm_c_define ("ENOBUFS", scm_from_int (ENOBUFS));
#endif
#ifdef ENOCSI
scm_c_define ("ENOCSI", scm_from_int (ENOCSI));
#endif
#ifdef ENODATA
scm_c_define ("ENODATA", scm_from_int (ENODATA));
#endif
#ifdef ENODEV
scm_c_define ("ENODEV", scm_from_int (ENODEV));
#endif
#ifdef ENOENT
scm_c_define ("ENOENT", scm_from_int (ENOENT));
#endif
#ifdef ENOEXEC
scm_c_define ("ENOEXEC", scm_from_int (ENOEXEC));
#endif
#ifdef ENOKEY
scm_c_define ("ENOKEY", scm_from_int (ENOKEY));
#endif
#ifdef ENOLCK
scm_c_define ("ENOLCK", scm_from_int (ENOLCK));
#endif
#ifdef ENOLINK
scm_c_define ("ENOLINK", scm_from_int (ENOLINK));
#endif
#ifdef ENOMEDIUM
scm_c_define ("ENOMEDIUM", scm_from_int (ENOMEDIUM));
#endif
#ifdef ENOMEM
scm_c_define ("ENOMEM", scm_from_int (ENOMEM));
#endif
#ifdef ENOMSG
scm_c_define ("ENOMSG", scm_from_int (ENOMSG));
#endif
#ifdef ENONET
scm_c_define ("ENONET", scm_from_int (ENONET));
#endif
#ifdef ENOPKG
scm_c_define ("ENOPKG", scm_from_int (ENOPKG));
#endif
#ifdef ENOPROTOOPT
scm_c_define ("ENOPROTOOPT", scm_from_int (ENOPROTOOPT));
#endif
#ifdef ENOSPC
scm_c_define ("ENOSPC", scm_from_int (ENOSPC));
#endif
#ifdef ENOSR
scm_c_define ("ENOSR", scm_from_int (ENOSR));
#endif
#ifdef ENOSTR
scm_c_define ("ENOSTR", scm_from_int (ENOSTR));
#endif
#ifdef ENOSYS
scm_c_define ("ENOSYS", scm_from_int (ENOSYS));
#endif
#ifdef ENOTBLK
scm_c_define ("ENOTBLK", scm_from_int (ENOTBLK));
#endif
#ifdef ENOTCONN
scm_c_define ("ENOTCONN", scm_from_int (ENOTCONN));
#endif
#ifdef ENOTDIR
scm_c_define ("ENOTDIR", scm_from_int (ENOTDIR));
#endif
#ifdef ENOTEMPTY
scm_c_define ("ENOTEMPTY", scm_from_int (ENOTEMPTY));
#endif
#ifdef ENOTNAM
scm_c_define ("ENOTNAM", scm_from_int (ENOTNAM));
#endif
#ifdef ENOTRECOVERABLE
scm_c_define ("ENOTRECOVERABLE", scm_from_int (ENOTRECOVERABLE));
#endif
#ifdef ENOTSOCK
scm_c_define ("ENOTSOCK", scm_from_int (ENOTSOCK));
#endif
#ifdef ENOTSUP
scm_c_define ("ENOTSUP", scm_from_int (ENOTSUP));
#endif
#ifdef ENOTTY
scm_c_define ("ENOTTY", scm_from_int (ENOTTY));
#endif
#ifdef ENOTUNIQ
scm_c_define ("ENOTUNIQ", scm_from_int (ENOTUNIQ));
#endif
#ifdef ENXIO
scm_c_define ("ENXIO", scm_from_int (ENXIO));
#endif
#ifdef EOPNOTSUPP
scm_c_define ("EOPNOTSUPP", scm_from_int (EOPNOTSUPP));
#endif
#ifdef EOVERFLOW
scm_c_define ("EOVERFLOW", scm_from_int (EOVERFLOW));
#endif
#ifdef EOWNERDEAD
scm_c_define ("EOWNERDEAD", scm_from_int (EOWNERDEAD));
#endif
#ifdef EPERM
scm_c_define ("EPERM", scm_from_int (EPERM));
#endif
#ifdef EPFNOSUPPORT
scm_c_define ("EPFNOSUPPORT", scm_from_int (EPFNOSUPPORT));
#endif
#ifdef EPIPE
scm_c_define ("EPIPE", scm_from_int (EPIPE));
#endif
#ifdef EPROCLIM
scm_c_define ("EPROCLIM", scm_from_int (EPROCLIM));
#endif
#ifdef EPROCUNAVAIL
scm_c_define ("EPROCUNAVAIL", scm_from_int (EPROCUNAVAIL));
#endif
#ifdef EPROGMISMATCH
scm_c_define ("EPROGMISMATCH", scm_from_int (EPROGMISMATCH));
#endif
#ifdef EPROGUNAVAIL
scm_c_define ("EPROGUNAVAIL", scm_from_int (EPROGUNAVAIL));
#endif
#ifdef EPROTO
scm_c_define ("EPROTO", scm_from_int (EPROTO));
#endif
#ifdef EPROTONOSUPPORT
scm_c_define ("EPROTONOSUPPORT", scm_from_int (EPROTONOSUPPORT));
#endif
#ifdef EPROTOTYPE
scm_c_define ("EPROTOTYPE", scm_from_int (EPROTOTYPE));
#endif
#ifdef ERANGE
scm_c_define ("ERANGE", scm_from_int (ERANGE));
#endif
#ifdef EREMCHG
scm_c_define ("EREMCHG", scm_from_int (EREMCHG));
#endif
#ifdef EREMOTE
scm_c_define ("EREMOTE", scm_from_int (EREMOTE));
#endif
#ifdef EREMOTEIO
scm_c_define ("EREMOTEIO", scm_from_int (EREMOTEIO));
#endif
#ifdef ERESTART
scm_c_define ("ERESTART", scm_from_int (ERESTART));
#endif
#ifdef ERFKILL
scm_c_define ("ERFKILL", scm_from_int (ERFKILL));
#endif
#ifdef EROFS
scm_c_define ("EROFS", scm_from_int (EROFS));
#endif
#ifdef ERPCMISMATCH
scm_c_define ("ERPCMISMATCH", scm_from_int (ERPCMISMATCH));
#endif
#ifdef ESHUTDOWN
scm_c_define ("ESHUTDOWN", scm_from_int (ESHUTDOWN));
#endif
#ifdef ESOCKTNOSUPPORT
scm_c_define ("ESOCKTNOSUPPORT", scm_from_int (ESOCKTNOSUPPORT));
#endif
#ifdef ESPIPE
scm_c_define ("ESPIPE", scm_from_int (ESPIPE));
#endif
#ifdef ESRCH
scm_c_define ("ESRCH", scm_from_int (ESRCH));
#endif
#ifdef ESRMNT
scm_c_define ("ESRMNT", scm_from_int (ESRMNT));
#endif
#ifdef ESTALE
scm_c_define ("ESTALE", scm_from_int (ESTALE));
#endif
#ifdef ESTRPIPE
scm_c_define ("ESTRPIPE", scm_from_int (ESTRPIPE));
#endif
#ifdef ETIME
scm_c_define ("ETIME", scm_from_int (ETIME));
#endif
#ifdef ETIMEDOUT
scm_c_define ("ETIMEDOUT", scm_from_int (ETIMEDOUT));
#endif
#ifdef ETOOMANYREFS
scm_c_define ("ETOOMANYREFS", scm_from_int (ETOOMANYREFS));
#endif
#ifdef ETXTBSY
scm_c_define ("ETXTBSY", scm_from_int (ETXTBSY));
#endif
#ifdef EUCLEAN
scm_c_define ("EUCLEAN", scm_from_int (EUCLEAN));
#endif
#ifdef EUNATCH
scm_c_define ("EUNATCH", scm_from_int (EUNATCH));
#endif
#ifdef EUSERS
scm_c_define ("EUSERS", scm_from_int (EUSERS));
#endif
#ifdef EWOULDBLOCK
scm_c_define ("EWOULDBLOCK", scm_from_int (EWOULDBLOCK));
#endif
#ifdef EXDEV
scm_c_define ("EXDEV", scm_from_int (EXDEV));
#endif
#ifdef EXFULL
scm_c_define ("EXFULL", scm_from_int (EXFULL));
#endif
